# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# pylint: disable=C0330, g-bad-import-order, g-multiple-import

"""Library for AI creative analysis.

Generates creative maps to be viewed via `https://filonov-ai.web.app/`.
"""

from filonov.creative_map import CreativeMap
from filonov.filonov_service import CreativeMapGenerateRequest, FilonovService

__all__ = [
  'FilonovService',
  'CreativeMapGenerateRequest',
  'CreativeMap',
]

__version__ = '0.7.0'
